K 25
svn:wc:ra_dav:version-url
V 57
/offlineimap/!svn/ver/130/offlineimap/head/offlineimap.py
END
